/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.isobus.type;

import java.io.IOException;
import java.util.List;
import java.util.regex.Pattern;
import javax.xml.parsers.ParserConfigurationException;
import nl.cloudfarming.client.geoviewer.SimpleLayer;
import nl.cloudfarming.client.isobus.model.IsobusGrid;
import org.openide.filesystems.FileObject;
import org.openide.loaders.*;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.lookup.Lookups;
import org.openide.util.lookup.ProxyLookup;
import org.xml.sax.SAXException;

public class GridDataObject extends MultiDataObject {

    private IsobusRaster raster;
    public static final String MIME_TYPE = "application/x-grid";
    private IsobusValueGrid valueGrid = null;
    private IsobusGrid grid = null;
    private FileObject pf;

    public GridDataObject(FileObject pf, MultiFileLoader loader, List<FileObject> secondary, FileObject taskDataFile) throws DataObjectExistsException, IOException {
        super(pf, loader);
        registerEditor(MIME_TYPE, true);
        this.pf = pf;

        setSecondaryFiles(secondary);

        DataObject dataObject = DataObject.find(taskDataFile);
        if (dataObject instanceof TaskDataObject) {
            TaskDataObject isobusDataObject = (TaskDataObject) dataObject;
            grid = isobusDataObject.getGrid(pf);
            valueGrid = GridReader.getValues(pf, grid, isobusDataObject.getTreatmentzones(pf));
        }
    }

    /**
     * Provides node that should represent this data object.
     *
     * @return the node representation
     * @see DataNode
     */
    @Override
    protected Node createNodeDelegate() {
        if (associateLookup() >= 1) {
            DataNode node = new DataNode(this, Children.LEAF, new ProxyLookup(getLookup(), Lookups.fixed(new SimpleLayer(pf.getName()), getIsobusRaster())));
            node.setIconBaseWithExtension("nl/cloudfarming/client/isobus/type/isobus_taskdata_grid.png");
            return node;
        }
        DataNode dataNode = (DataNode) super.createNodeDelegate();
        return dataNode;
    }

    @Override
    protected int associateLookup() {
        return 1;
    }

    /**
     * get the IsobusRaster which is build from the data in the binary file
     *
     * @return
     */
    public IsobusRaster getIsobusRaster() {
        if (raster == null) {
            if (grid != null) {
                raster = new IsobusRaster(grid, valueGrid);
            }
        }
        return raster;
    }

    /**
     * Method to set the secondary files
     *
     * @param secondary the secondary files
     */
    private void setSecondaryFiles(List<FileObject> secondary) {
        for (FileObject fileObject : secondary) {
            registerEntry(fileObject);
        }
    }
}
