/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.isobus.type;

import java.io.IOException;
import nl.cloudfarming.client.isobus.model.IsobusManager;
import nl.cloudfarming.client.logging.AppLogFactory;
import nl.cloudfarming.client.logging.AppLogger;
import org.netbeans.api.project.Project;
import org.openide.filesystems.FileObject;
import org.openide.util.Exceptions;
import org.openide.util.lookup.ServiceProvider;

/**
 * Implementation of isobusManager Is able to import and export TASKDATA.XML
 * files
 *
 * @author Merijn Zengers
 */
@ServiceProvider(service = IsobusManager.class)
public class IsobusManagerImpl implements IsobusManager {

    public final static String ISOBUS_FOLDER = "ISO11783";
    private static final AppLogger LOG = AppLogFactory.getLogger(IsobusManagerImpl.class);


    /**
     * Get all the taskdata folders from the provided project These folders
     * contain a TASKDATA.XML and optional GRD.BIN ,TLG.BIN and TLG.XML files
     *
     * @param project the project to search in
     * @return the found folders or empty array if there are no children
     */
    @Override
    public FileObject[] getTaskDataFolders(Project project) {
        FileObject isobusFolder = getIsobusFolder(project);
        return isobusFolder.getChildren();
    }

    /**
     * Returns isobusfolder inside the specified project Protected for
     * unittesting purposes!
     *
     * @param project Project to get isobusfolder from.
     * @return Isobusfolder on the filesystem
     */
    @Override
    public FileObject getIsobusFolder(Project project) {
        FileObject isobusFolder = project.getProjectDirectory().getFileObject(ISOBUS_FOLDER);
        // Create Isobusfolder if it doesn't exist
        if (isobusFolder == null) {
            try {
                isobusFolder = project.getProjectDirectory().createFolder(ISOBUS_FOLDER);
            } catch (IOException ex) {
                Exceptions.printStackTrace(ex);
            }
        }
        return isobusFolder;
    }


}
