/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.isobus.type;

/**
 * storage for a grid of raw process data values.
 * 
 * @author johan
 */
public class IsobusValueGrid {
    private final int[][] grid; // match type of ProcessDataVariable.ProcessDataValue
    private final int numberOfColumns;
    private final int numberOfRows;
    
    public IsobusValueGrid(int numberOfRows, int numberOfColumn){
        grid = new int[numberOfRows][numberOfColumn];
        this.numberOfRows = numberOfRows;
        this.numberOfColumns = numberOfColumn;
    }
    
    public void insert(int row, int column, int value) {
        grid[row][column] = value;
    }
    
    public int getValue(int row, int column) {
        return grid[row][column];
    }

    public int[] getValues() {
        // merge grid into single array for use with raster:
        int[] allValues = new int[getSize()];
        
        for (int i = 0, offset = 0; i < numberOfRows; i++, offset += numberOfColumns) {
            System.arraycopy(grid[i], 0, allValues, offset, numberOfColumns);
        }
        return allValues;
    }

    public int getNumberOfColumns() {
        return numberOfColumns;
    }

    public int getNumberOfRows() {
        return numberOfRows;
    }
    
    public int getSize(){
        return numberOfColumns * numberOfRows;
    }
}
